---
test_data: TD_27_59_80_86
test_title: single data envelope arg suggestion and consumption
---

This data tests these rules from FS_13_51_07_97 singled out implicit values:
*   If there is already single `data_envelope` found, then do not suggest remaining `prop_name`-s (to save human time).
*   But if user puts an `arg_value` matching the single value from the remaining `prop_name`-s, consume it.

See also both:
*   FS_13_51_07_97 for singled out implicit values.
*   FS_90_48_11_45 always consume `dictated_arg`
